/***************************************************************************
                          dcopiface_shell.cpp  -  description
                             -------------------
    begin                : Tue Oct 23 2001
    copyright            : (C) 2001, 2002, 2003 by The KXMLEditor Team
    email                : lvanek@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dcopiface_shell.h"
#include "kxmleditorshell.h"

QString
KXMLEditorShellIface::Quit()
{
//	m_pKXEShell->close();
	m_KXEShell.close();
	return "";

}


void
KXMLEditorShellIface::FileOpen()
{
	m_KXEShell.slotFileOpen();
}




